@@ -45,6 +45,12 @@ Numbat <- R6::R6Class("Numbat", lock_objects=FALSE,
     #' @field gexp_roll_wide matrix Smoothed expression of single cells
     gexp_roll_wide = NULL,
 
+    #' @field P matrix Genotype probability matrix
+    P = NULL,
+
+    #' @field treeML matrix Maximum likelihood tree as phylo object
+    treeML = NULL,
+
     #' @field hc hclust Initial hierarchical clustering
     hc = NULL,
 
@@ -147,6 +153,17 @@ Numbat <- R6::R6Class("Numbat", lock_objects=FALSE,
                 ...
             )
         return(p)
+    },
+
+    #' @description Re-define subclones on the phylogeny. 
+    #' @param max_cost numeric Likelihood threshold to collapse internal branches
+    #' @param n_cut integer Number of cuts on the phylogeny to define subclones
+    cutree = function(max_cost = 0, n_cut = 0) {
+        
+        self$gtree = get_gtree(self$treeML, self$P, max_cost = max_cost, n_cut = n_cut)
+        self$mut_graph = scistreer::get_mut_graph(self$gtree)
+        self$clone_post = get_clone_post(self$gtree, self$exp_post, self$allele_post)
+
     }),
 
     ## Private functions
@@ -163,13 +180,9 @@ Numbat <- R6::R6Class("Numbat", lock_objects=FALSE,
         fetch_results = function(out_dir, i = 2) {
  
             self$joint_post = read_file(inputfile=glue('{out_dir}/joint_post_{i}.tsv'), filetype="tsv")
-
             self$exp_post = read_file(inputfile=glue('{out_dir}/exp_post_{i}.tsv'), filetype="tsv")
-
             self$allele_post = read_file(inputfile=glue('{out_dir}/allele_post_{i}.tsv'), filetype="tsv")
-
             self$bulk_clones = read_file(inputfile=glue('{out_dir}/bulk_clones_final.tsv.gz'), filetype="tsv")
-  
             self$segs_consensus = read_file(inputfile=glue('{out_dir}/segs_consensus_{i}.tsv'), filetype="tsv")
 
             self$segs_consensus = self$segs_consensus %>% relevel_chrom()
@@ -178,12 +191,11 @@ Numbat <- R6::R6Class("Numbat", lock_objects=FALSE,
             self$allele_post = self$allele_post %>% relevel_chrom()
             self$bulk_clones = self$bulk_clones %>% relevel_chrom()
             
-            self$tree_post = read_file(inputfile=glue('{out_dir}/tree_post_{i}.rds'), filetype="rds")
+            self$P = read_file(inputfile=glue('{out_dir}/geno_{i}.tsv')) %>% tibble::column_to_rownames('cell') %>% as.matrix
+            self$treeML = read_file(inputfile=glue('{out_dir}/treeML_{i}.rds'), filetype="rds")
             self$mut_graph = read_file(inputfile=glue('{out_dir}/mut_graph_{i}.rds'), filetype="rds")
             self$gtree = read_file(inputfile=glue('{out_dir}/tree_final_{i}.rds'), filetype="rds")
             self$clone_post = read_file(inputfile=glue('{out_dir}/clone_post_{i}.tsv'), filetype="tsv")
-            
-            self$hc = read_hc_rds(inputfile=glue('{out_dir}/hc.rds'))
-            
+
     })
 )
\ No newline at end of file
